"""
Recip -- Sage package for using Shimura's reciprocity law

When using this package in a publication, it is probably approprate to
cite the following, or preferably a future published version. (This package is
based on formulas from that paper, is motivated by it, and contains examples
from it.)

[1] Marco Streng -- An explicit version of Shimura's reciprocity law for Siegel
    modular functions. arXiv:1201.0020

#*****************************************************************************
# Copyright (C) 2010 -- 2012 Marco Streng <marco.streng@gmail.com>
# 
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
#*****************************************************************************

To use this package, start Sage with the .sage files from this package in your
working directory. Then type::

    sage: load("main.sage")

See the file article.sage for examples related directly to [1].

The current version of this package is suitable when working with theta
characteristics in (1/den)ZZ and g-dimensional abelian varieties where
den^(2*g) is small and den is even (e.g. g=den=2). This already allows for
class invariants that yield a significant improvement in size relative to Igusa
invariants.

"""

load_attach_mode(load_debug=True)

load "basic.sage"
load "polynomials.sage"
load "symplectic_matrices.sage"
load "period_matrices.sage"
load "theta_trans.sage"
load "cm_types.sage"
load "find_class_invariant.sage"
load "igusa_invariants.sage"
load "list_fields.sage"
load "denominators.sage"
load "class_polynomials.sage"

recip_verbose = 0

def set_recip_verbose(level):
    """
    Sets the verbosity level for the Recip package.
    """
    global recip_verbose
    recip_verbose = level

def get_recip_verbose():
    """
    Returns the verbosity level for the Recip package.
    """
    try:
        return recip_verbose
    except NameError:
        recip_verbose = 0
        return 0
    
